# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import os
import re
from typing import (
    Dict,
    Mapping,
    MutableMapping,
    MutableSequence,
    Optional,
    Iterable,
    Iterator,
    Sequence,
    Tuple,
    Type,
    Union,
    cast,
)

from google.cloud.dialogflowcx_v3 import gapic_version as package_version

from google.api_core import client_options as client_options_lib
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport import mtls  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
from google.auth.exceptions import MutualTLSChannelError  # type: ignore
from google.oauth2 import service_account  # type: ignore

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object]  # type: ignore

from google.cloud.dialogflowcx_v3.types import audio_config
from google.cloud.dialogflowcx_v3.types import page
from google.cloud.dialogflowcx_v3.types import session
from google.cloud.location import locations_pb2  # type: ignore
from google.longrunning import operations_pb2
from .transports.base import SessionsTransport, DEFAULT_CLIENT_INFO
from .transports.grpc import SessionsGrpcTransport
from .transports.grpc_asyncio import SessionsGrpcAsyncIOTransport
from .transports.rest import SessionsRestTransport


class SessionsClientMeta(type):
    """Metaclass for the Sessions client.

    This provides class-level methods for building and retrieving
    support objects (e.g. transport) without polluting the client instance
    objects.
    """

    _transport_registry = OrderedDict()  # type: Dict[str, Type[SessionsTransport]]
    _transport_registry["grpc"] = SessionsGrpcTransport
    _transport_registry["grpc_asyncio"] = SessionsGrpcAsyncIOTransport
    _transport_registry["rest"] = SessionsRestTransport

    def get_transport_class(
        cls,
        label: Optional[str] = None,
    ) -> Type[SessionsTransport]:
        """Returns an appropriate transport class.

        Args:
            label: The name of the desired transport. If none is
                provided, then the first transport in the registry is used.

        Returns:
            The transport class to use.
        """
        # If a specific transport is requested, return that one.
        if label:
            return cls._transport_registry[label]

        # No transport is requested; return the default (that is, the first one
        # in the dictionary).
        return next(iter(cls._transport_registry.values()))


class SessionsClient(metaclass=SessionsClientMeta):
    """A session represents an interaction with a user. You retrieve user
    input and pass it to the
    [DetectIntent][google.cloud.dialogflow.cx.v3.Sessions.DetectIntent]
    method to determine user intent and respond.
    """

    @staticmethod
    def _get_default_mtls_endpoint(api_endpoint):
        """Converts api endpoint to mTLS endpoint.

        Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
        "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
        Args:
            api_endpoint (Optional[str]): the api endpoint to convert.
        Returns:
            str: converted mTLS api endpoint.
        """
        if not api_endpoint:
            return api_endpoint

        mtls_endpoint_re = re.compile(
            r"(?P<name>[^.]+)(?P<mtls>\.mtls)?(?P<sandbox>\.sandbox)?(?P<googledomain>\.googleapis\.com)?"
        )

        m = mtls_endpoint_re.match(api_endpoint)
        name, mtls, sandbox, googledomain = m.groups()
        if mtls or not googledomain:
            return api_endpoint

        if sandbox:
            return api_endpoint.replace(
                "sandbox.googleapis.com", "mtls.sandbox.googleapis.com"
            )

        return api_endpoint.replace(".googleapis.com", ".mtls.googleapis.com")

    DEFAULT_ENDPOINT = "dialogflow.googleapis.com"
    DEFAULT_MTLS_ENDPOINT = _get_default_mtls_endpoint.__func__(  # type: ignore
        DEFAULT_ENDPOINT
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            SessionsClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_info(info)
        kwargs["credentials"] = credentials
        return cls(*args, **kwargs)

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            SessionsClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(filename)
        kwargs["credentials"] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @property
    def transport(self) -> SessionsTransport:
        """Returns the transport used by the client instance.

        Returns:
            SessionsTransport: The transport used by the client
                instance.
        """
        return self._transport

    @staticmethod
    def entity_type_path(
        project: str,
        location: str,
        agent: str,
        entity_type: str,
    ) -> str:
        """Returns a fully-qualified entity_type string."""
        return "projects/{project}/locations/{location}/agents/{agent}/entityTypes/{entity_type}".format(
            project=project,
            location=location,
            agent=agent,
            entity_type=entity_type,
        )

    @staticmethod
    def parse_entity_type_path(path: str) -> Dict[str, str]:
        """Parses a entity_type path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/entityTypes/(?P<entity_type>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def flow_path(
        project: str,
        location: str,
        agent: str,
        flow: str,
    ) -> str:
        """Returns a fully-qualified flow string."""
        return "projects/{project}/locations/{location}/agents/{agent}/flows/{flow}".format(
            project=project,
            location=location,
            agent=agent,
            flow=flow,
        )

    @staticmethod
    def parse_flow_path(path: str) -> Dict[str, str]:
        """Parses a flow path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/flows/(?P<flow>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def intent_path(
        project: str,
        location: str,
        agent: str,
        intent: str,
    ) -> str:
        """Returns a fully-qualified intent string."""
        return "projects/{project}/locations/{location}/agents/{agent}/intents/{intent}".format(
            project=project,
            location=location,
            agent=agent,
            intent=intent,
        )

    @staticmethod
    def parse_intent_path(path: str) -> Dict[str, str]:
        """Parses a intent path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/intents/(?P<intent>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def page_path(
        project: str,
        location: str,
        agent: str,
        flow: str,
        page: str,
    ) -> str:
        """Returns a fully-qualified page string."""
        return "projects/{project}/locations/{location}/agents/{agent}/flows/{flow}/pages/{page}".format(
            project=project,
            location=location,
            agent=agent,
            flow=flow,
            page=page,
        )

    @staticmethod
    def parse_page_path(path: str) -> Dict[str, str]:
        """Parses a page path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/flows/(?P<flow>.+?)/pages/(?P<page>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def session_path(
        project: str,
        location: str,
        agent: str,
        session: str,
    ) -> str:
        """Returns a fully-qualified session string."""
        return "projects/{project}/locations/{location}/agents/{agent}/sessions/{session}".format(
            project=project,
            location=location,
            agent=agent,
            session=session,
        )

    @staticmethod
    def parse_session_path(path: str) -> Dict[str, str]:
        """Parses a session path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/sessions/(?P<session>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def session_entity_type_path(
        project: str,
        location: str,
        agent: str,
        session: str,
        entity_type: str,
    ) -> str:
        """Returns a fully-qualified session_entity_type string."""
        return "projects/{project}/locations/{location}/agents/{agent}/sessions/{session}/entityTypes/{entity_type}".format(
            project=project,
            location=location,
            agent=agent,
            session=session,
            entity_type=entity_type,
        )

    @staticmethod
    def parse_session_entity_type_path(path: str) -> Dict[str, str]:
        """Parses a session_entity_type path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/sessions/(?P<session>.+?)/entityTypes/(?P<entity_type>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def transition_route_group_path(
        project: str,
        location: str,
        agent: str,
        flow: str,
        transition_route_group: str,
    ) -> str:
        """Returns a fully-qualified transition_route_group string."""
        return "projects/{project}/locations/{location}/agents/{agent}/flows/{flow}/transitionRouteGroups/{transition_route_group}".format(
            project=project,
            location=location,
            agent=agent,
            flow=flow,
            transition_route_group=transition_route_group,
        )

    @staticmethod
    def parse_transition_route_group_path(path: str) -> Dict[str, str]:
        """Parses a transition_route_group path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/flows/(?P<flow>.+?)/transitionRouteGroups/(?P<transition_route_group>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def version_path(
        project: str,
        location: str,
        agent: str,
        flow: str,
        version: str,
    ) -> str:
        """Returns a fully-qualified version string."""
        return "projects/{project}/locations/{location}/agents/{agent}/flows/{flow}/versions/{version}".format(
            project=project,
            location=location,
            agent=agent,
            flow=flow,
            version=version,
        )

    @staticmethod
    def parse_version_path(path: str) -> Dict[str, str]:
        """Parses a version path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/flows/(?P<flow>.+?)/versions/(?P<version>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def webhook_path(
        project: str,
        location: str,
        agent: str,
        webhook: str,
    ) -> str:
        """Returns a fully-qualified webhook string."""
        return "projects/{project}/locations/{location}/agents/{agent}/webhooks/{webhook}".format(
            project=project,
            location=location,
            agent=agent,
            webhook=webhook,
        )

    @staticmethod
    def parse_webhook_path(path: str) -> Dict[str, str]:
        """Parses a webhook path into its component segments."""
        m = re.match(
            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/agents/(?P<agent>.+?)/webhooks/(?P<webhook>.+?)$",
            path,
        )
        return m.groupdict() if m else {}

    @staticmethod
    def common_billing_account_path(
        billing_account: str,
    ) -> str:
        """Returns a fully-qualified billing_account string."""
        return "billingAccounts/{billing_account}".format(
            billing_account=billing_account,
        )

    @staticmethod
    def parse_common_billing_account_path(path: str) -> Dict[str, str]:
        """Parse a billing_account path into its component segments."""
        m = re.match(r"^billingAccounts/(?P<billing_account>.+?)$", path)
        return m.groupdict() if m else {}

    @staticmethod
    def common_folder_path(
        folder: str,
    ) -> str:
        """Returns a fully-qualified folder string."""
        return "folders/{folder}".format(
            folder=folder,
        )

    @staticmethod
    def parse_common_folder_path(path: str) -> Dict[str, str]:
        """Parse a folder path into its component segments."""
        m = re.match(r"^folders/(?P<folder>.+?)$", path)
        return m.groupdict() if m else {}

    @staticmethod
    def common_organization_path(
        organization: str,
    ) -> str:
        """Returns a fully-qualified organization string."""
        return "organizations/{organization}".format(
            organization=organization,
        )

    @staticmethod
    def parse_common_organization_path(path: str) -> Dict[str, str]:
        """Parse a organization path into its component segments."""
        m = re.match(r"^organizations/(?P<organization>.+?)$", path)
        return m.groupdict() if m else {}

    @staticmethod
    def common_project_path(
        project: str,
    ) -> str:
        """Returns a fully-qualified project string."""
        return "projects/{project}".format(
            project=project,
        )

    @staticmethod
    def parse_common_project_path(path: str) -> Dict[str, str]:
        """Parse a project path into its component segments."""
        m = re.match(r"^projects/(?P<project>.+?)$", path)
        return m.groupdict() if m else {}

    @staticmethod
    def common_location_path(
        project: str,
        location: str,
    ) -> str:
        """Returns a fully-qualified location string."""
        return "projects/{project}/locations/{location}".format(
            project=project,
            location=location,
        )

    @staticmethod
    def parse_common_location_path(path: str) -> Dict[str, str]:
        """Parse a location path into its component segments."""
        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
        return m.groupdict() if m else {}

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[client_options_lib.ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variable is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        if client_options is None:
            client_options = client_options_lib.ClientOptions()
        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
        if use_client_cert not in ("true", "false"):
            raise ValueError(
                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
            )
        if use_mtls_endpoint not in ("auto", "never", "always"):
            raise MutualTLSChannelError(
                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
            )

        # Figure out the client cert source to use.
        client_cert_source = None
        if use_client_cert == "true":
            if client_options.client_cert_source:
                client_cert_source = client_options.client_cert_source
            elif mtls.has_default_client_cert_source():
                client_cert_source = mtls.default_client_cert_source()

        # Figure out which api endpoint to use.
        if client_options.api_endpoint is not None:
            api_endpoint = client_options.api_endpoint
        elif use_mtls_endpoint == "always" or (
            use_mtls_endpoint == "auto" and client_cert_source
        ):
            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
        else:
            api_endpoint = cls.DEFAULT_ENDPOINT

        return api_endpoint, client_cert_source

    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = None,
        transport: Optional[Union[str, SessionsTransport]] = None,
        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the sessions client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, SessionsTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                client. It won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        if isinstance(client_options, dict):
            client_options = client_options_lib.from_dict(client_options)
        if client_options is None:
            client_options = client_options_lib.ClientOptions()
        client_options = cast(client_options_lib.ClientOptions, client_options)

        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
            client_options
        )

        api_key_value = getattr(client_options, "api_key", None)
        if api_key_value and credentials:
            raise ValueError(
                "client_options.api_key and credentials are mutually exclusive"
            )

        # Save or instantiate the transport.
        # Ordinarily, we provide the transport, but allowing a custom transport
        # instance provides an extensibility point for unusual situations.
        if isinstance(transport, SessionsTransport):
            # transport is a SessionsTransport instance.
            if credentials or client_options.credentials_file or api_key_value:
                raise ValueError(
                    "When providing a transport instance, "
                    "provide its credentials directly."
                )
            if client_options.scopes:
                raise ValueError(
                    "When providing a transport instance, provide its scopes "
                    "directly."
                )
            self._transport = transport
        else:
            import google.auth._default  # type: ignore

            if api_key_value and hasattr(
                google.auth._default, "get_api_key_credentials"
            ):
                credentials = google.auth._default.get_api_key_credentials(
                    api_key_value
                )

            Transport = type(self).get_transport_class(transport)
            self._transport = Transport(
                credentials=credentials,
                credentials_file=client_options.credentials_file,
                host=api_endpoint,
                scopes=client_options.scopes,
                client_cert_source_for_mtls=client_cert_source_func,
                quota_project_id=client_options.quota_project_id,
                client_info=client_info,
                always_use_jwt_access=True,
                api_audience=client_options.api_audience,
            )

    def detect_intent(
        self,
        request: Optional[Union[session.DetectIntentRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> session.DetectIntentResponse:
        r"""Processes a natural language query and returns structured,
        actionable data as a result. This method is not idempotent,
        because it may cause session entity types to be updated, which
        in turn might affect results of future queries.

        Note: Always use agent versions for production traffic. See
        `Versions and
        environments <https://cloud.google.com/dialogflow/cx/docs/concept/version>`__.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import dialogflowcx_v3

            def sample_detect_intent():
                # Create a client
                client = dialogflowcx_v3.SessionsClient()

                # Initialize request argument(s)
                query_input = dialogflowcx_v3.QueryInput()
                query_input.text.text = "text_value"
                query_input.language_code = "language_code_value"

                request = dialogflowcx_v3.DetectIntentRequest(
                    session="session_value",
                    query_input=query_input,
                )

                # Make the request
                response = client.detect_intent(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.dialogflowcx_v3.types.DetectIntentRequest, dict]):
                The request object. The request to detect user's intent.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.dialogflowcx_v3.types.DetectIntentResponse:
                The message returned from the
                DetectIntent method.

        """
        # Create or coerce a protobuf request object.
        # Minor optimization to avoid making a copy if the user passes
        # in a session.DetectIntentRequest.
        # There's no risk of modifying the input as we've already verified
        # there are no flattened fields.
        if not isinstance(request, session.DetectIntentRequest):
            request = session.DetectIntentRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._transport._wrapped_methods[self._transport.detect_intent]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("session", request.session),)),
        )

        # Send the request.
        response = rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    def streaming_detect_intent(
        self,
        requests: Optional[Iterator[session.StreamingDetectIntentRequest]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> Iterable[session.StreamingDetectIntentResponse]:
        r"""Processes a natural language query in audio format in a
        streaming fashion and returns structured, actionable data as a
        result. This method is only available via the gRPC API (not
        REST).

        Note: Always use agent versions for production traffic. See
        `Versions and
        environments <https://cloud.google.com/dialogflow/cx/docs/concept/version>`__.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import dialogflowcx_v3

            def sample_streaming_detect_intent():
                # Create a client
                client = dialogflowcx_v3.SessionsClient()

                # Initialize request argument(s)
                query_input = dialogflowcx_v3.QueryInput()
                query_input.text.text = "text_value"
                query_input.language_code = "language_code_value"

                request = dialogflowcx_v3.StreamingDetectIntentRequest(
                    query_input=query_input,
                )

                # This method expects an iterator which contains
                # 'dialogflowcx_v3.StreamingDetectIntentRequest' objects
                # Here we create a generator that yields a single `request` for
                # demonstrative purposes.
                requests = [request]

                def request_generator():
                    for request in requests:
                        yield request

                # Make the request
                stream = client.streaming_detect_intent(requests=request_generator())

                # Handle the response
                for response in stream:
                    print(response)

        Args:
            requests (Iterator[google.cloud.dialogflowcx_v3.types.StreamingDetectIntentRequest]):
                The request object iterator. The top-level message sent by the client to the
                [Sessions.StreamingDetectIntent][google.cloud.dialogflow.cx.v3.Sessions.StreamingDetectIntent]
                method.

                Multiple request messages should be sent in order:

                1. The first message must contain
                   [session][google.cloud.dialogflow.cx.v3.StreamingDetectIntentRequest.session],
                   [query_input][google.cloud.dialogflow.cx.v3.StreamingDetectIntentRequest.query_input]
                   plus optionally
                   [query_params][google.cloud.dialogflow.cx.v3.StreamingDetectIntentRequest.query_params].
                   If the client wants to receive an audio response, it
                   should also contain
                   [output_audio_config][google.cloud.dialogflow.cx.v3.StreamingDetectIntentRequest.output_audio_config].

                2. If
                   [query_input][google.cloud.dialogflow.cx.v3.StreamingDetectIntentRequest.query_input]
                   was set to
                   [query_input.audio.config][google.cloud.dialogflow.cx.v3.AudioInput.config],
                   all subsequent messages must contain
                   [query_input.audio.audio][google.cloud.dialogflow.cx.v3.AudioInput.audio]
                   to continue with Speech recognition. If you decide to
                   rather detect an intent from text input after you
                   already started Speech recognition, please send a
                   message with
                   [query_input.text][google.cloud.dialogflow.cx.v3.QueryInput.text].

                   However, note that:

                   -  Dialogflow will bill you for the audio duration so
                      far.
                   -  Dialogflow discards all Speech recognition results
                      in favor of the input text.
                   -  Dialogflow will use the language code from the
                      first message.

                After you sent all input, you must half-close or abort
                the request stream.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            Iterable[google.cloud.dialogflowcx_v3.types.StreamingDetectIntentResponse]:
                The top-level message returned from the
                   [StreamingDetectIntent][google.cloud.dialogflow.cx.v3.Sessions.StreamingDetectIntent]
                   method.

                   Multiple response messages (N) can be returned in
                   order.

                   The first (N-1) responses set either the
                   recognition_result or detect_intent_response field,
                   depending on the request:

                   -  If the
                      StreamingDetectIntentRequest.query_input.audio
                      field was set, and the
                      StreamingDetectIntentRequest.enable_partial_response
                      field was false, the recognition_result field is
                      populated for each of the (N-1) responses. See the
                      [StreamingRecognitionResult][google.cloud.dialogflow.cx.v3.StreamingRecognitionResult]
                      message for details about the result message
                      sequence.
                   -  If the
                      StreamingDetectIntentRequest.enable_partial_response
                      field was true, the detect_intent_response field
                      is populated for each of the (N-1) responses,
                      where 1 <= N <= 4. These responses set the
                      [DetectIntentResponse.response_type][google.cloud.dialogflow.cx.v3.DetectIntentResponse.response_type]
                      field to PARTIAL.

                   For the final Nth response message, the
                   detect_intent_response is fully populated, and
                   [DetectIntentResponse.response_type][google.cloud.dialogflow.cx.v3.DetectIntentResponse.response_type]
                   is set to FINAL.

        """

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._transport._wrapped_methods[self._transport.streaming_detect_intent]

        # Send the request.
        response = rpc(
            requests,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    def match_intent(
        self,
        request: Optional[Union[session.MatchIntentRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> session.MatchIntentResponse:
        r"""Returns preliminary intent match results, doesn't
        change the session status.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import dialogflowcx_v3

            def sample_match_intent():
                # Create a client
                client = dialogflowcx_v3.SessionsClient()

                # Initialize request argument(s)
                query_input = dialogflowcx_v3.QueryInput()
                query_input.text.text = "text_value"
                query_input.language_code = "language_code_value"

                request = dialogflowcx_v3.MatchIntentRequest(
                    session="session_value",
                    query_input=query_input,
                )

                # Make the request
                response = client.match_intent(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.dialogflowcx_v3.types.MatchIntentRequest, dict]):
                The request object. Request of [MatchIntent][].
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.dialogflowcx_v3.types.MatchIntentResponse:
                Response of [MatchIntent][].
        """
        # Create or coerce a protobuf request object.
        # Minor optimization to avoid making a copy if the user passes
        # in a session.MatchIntentRequest.
        # There's no risk of modifying the input as we've already verified
        # there are no flattened fields.
        if not isinstance(request, session.MatchIntentRequest):
            request = session.MatchIntentRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._transport._wrapped_methods[self._transport.match_intent]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("session", request.session),)),
        )

        # Send the request.
        response = rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    def fulfill_intent(
        self,
        request: Optional[Union[session.FulfillIntentRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> session.FulfillIntentResponse:
        r"""Fulfills a matched intent returned by
        [MatchIntent][google.cloud.dialogflow.cx.v3.Sessions.MatchIntent].
        Must be called after
        [MatchIntent][google.cloud.dialogflow.cx.v3.Sessions.MatchIntent],
        with input from
        [MatchIntentResponse][google.cloud.dialogflow.cx.v3.MatchIntentResponse].
        Otherwise, the behavior is undefined.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import dialogflowcx_v3

            def sample_fulfill_intent():
                # Create a client
                client = dialogflowcx_v3.SessionsClient()

                # Initialize request argument(s)
                request = dialogflowcx_v3.FulfillIntentRequest(
                )

                # Make the request
                response = client.fulfill_intent(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.dialogflowcx_v3.types.FulfillIntentRequest, dict]):
                The request object. Request of [FulfillIntent][]
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.dialogflowcx_v3.types.FulfillIntentResponse:
                Response of [FulfillIntent][]
        """
        # Create or coerce a protobuf request object.
        # Minor optimization to avoid making a copy if the user passes
        # in a session.FulfillIntentRequest.
        # There's no risk of modifying the input as we've already verified
        # there are no flattened fields.
        if not isinstance(request, session.FulfillIntentRequest):
            request = session.FulfillIntentRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._transport._wrapped_methods[self._transport.fulfill_intent]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata(
                (
                    (
                        "match_intent_request.session",
                        request.match_intent_request.session,
                    ),
                )
            ),
        )

        # Send the request.
        response = rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    def __enter__(self) -> "SessionsClient":
        return self

    def __exit__(self, type, value, traceback):
        """Releases underlying transport's resources.

        .. warning::
            ONLY use as a context manager if the transport is NOT shared
            with other clients! Exiting the with block will CLOSE the transport
            and may cause errors in other clients!
        """
        self.transport.close()

    def list_operations(
        self,
        request: Optional[operations_pb2.ListOperationsRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operations_pb2.ListOperationsResponse:
        r"""Lists operations that match the specified filter in the request.

        Args:
            request (:class:`~.operations_pb2.ListOperationsRequest`):
                The request object. Request message for
                `ListOperations` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.operations_pb2.ListOperationsResponse:
                Response message for ``ListOperations`` method.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.ListOperationsRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._transport.list_operations,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    def get_operation(
        self,
        request: Optional[operations_pb2.GetOperationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operations_pb2.Operation:
        r"""Gets the latest state of a long-running operation.

        Args:
            request (:class:`~.operations_pb2.GetOperationRequest`):
                The request object. Request message for
                `GetOperation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.operations_pb2.Operation:
                An ``Operation`` object.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.GetOperationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._transport.get_operation,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    def cancel_operation(
        self,
        request: Optional[operations_pb2.CancelOperationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Starts asynchronous cancellation on a long-running operation.

        The server makes a best effort to cancel the operation, but success
        is not guaranteed.  If the server doesn't support this method, it returns
        `google.rpc.Code.UNIMPLEMENTED`.

        Args:
            request (:class:`~.operations_pb2.CancelOperationRequest`):
                The request object. Request message for
                `CancelOperation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            None
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.CancelOperationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._transport.cancel_operation,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    def get_location(
        self,
        request: Optional[locations_pb2.GetLocationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> locations_pb2.Location:
        r"""Gets information about a location.

        Args:
            request (:class:`~.location_pb2.GetLocationRequest`):
                The request object. Request message for
                `GetLocation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                 if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.location_pb2.Location:
                Location object.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = locations_pb2.GetLocationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._transport.get_location,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    def list_locations(
        self,
        request: Optional[locations_pb2.ListLocationsRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> locations_pb2.ListLocationsResponse:
        r"""Lists information about the supported locations for this service.

        Args:
            request (:class:`~.location_pb2.ListLocationsRequest`):
                The request object. Request message for
                `ListLocations` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                 if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.location_pb2.ListLocationsResponse:
                Response message for ``ListLocations`` method.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = locations_pb2.ListLocationsRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._transport.list_locations,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response


DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


__all__ = ("SessionsClient",)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "GetSecuritySettingsRequest",
        "UpdateSecuritySettingsRequest",
        "ListSecuritySettingsRequest",
        "ListSecuritySettingsResponse",
        "CreateSecuritySettingsRequest",
        "DeleteSecuritySettingsRequest",
        "SecuritySettings",
    },
)


class GetSecuritySettingsRequest(proto.Message):
    r"""The request message for
    [SecuritySettingsService.GetSecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettingsService.GetSecuritySettings].

    Attributes:
        name (str):
            Required. Resource name of the settings. Format:
            ``projects/<Project ID>/locations/<Location ID>/securitySettings/<security settings ID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateSecuritySettingsRequest(proto.Message):
    r"""The request message for
    [SecuritySettingsService.UpdateSecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettingsService.UpdateSecuritySettings].

    Attributes:
        security_settings (google.cloud.dialogflowcx_v3beta1.types.SecuritySettings):
            Required. [SecuritySettings] object that contains values for
            each of the fields to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The mask to control which fields
            get updated. If the mask is not present, all
            fields will be updated.
    """

    security_settings: "SecuritySettings" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="SecuritySettings",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class ListSecuritySettingsRequest(proto.Message):
    r"""The request message for [SecuritySettings.ListSecuritySettings][].

    Attributes:
        parent (str):
            Required. The location to list all security settings for.
            Format: ``projects/<Project ID>/locations/<Location ID>``.
        page_size (int):
            The maximum number of items to return in a
            single page. By default 20 and at most 100.
        page_token (str):
            The next_page_token value returned from a previous list
            request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListSecuritySettingsResponse(proto.Message):
    r"""The response message for [SecuritySettings.ListSecuritySettings][].

    Attributes:
        security_settings (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.SecuritySettings]):
            The list of security settings.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    security_settings: MutableSequence["SecuritySettings"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="SecuritySettings",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CreateSecuritySettingsRequest(proto.Message):
    r"""The request message for [SecuritySettings.CreateSecuritySettings][].

    Attributes:
        parent (str):
            Required. The location to create an
            [SecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettings]
            for. Format:
            ``projects/<Project ID>/locations/<Location ID>``.
        security_settings (google.cloud.dialogflowcx_v3beta1.types.SecuritySettings):
            Required. The security settings to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    security_settings: "SecuritySettings" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="SecuritySettings",
    )


class DeleteSecuritySettingsRequest(proto.Message):
    r"""The request message for [SecuritySettings.DeleteSecuritySettings][].

    Attributes:
        name (str):
            Required. The name of the
            [SecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettings]
            to delete. Format:
            ``projects/<Project ID>/locations/<Location ID>/securitySettings/<Security Settings ID>``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class SecuritySettings(proto.Message):
    r"""Represents the settings related to security issues, such as
    data redaction and data retention. It may take hours for updates
    on the settings to propagate to all the related components and
    take effect.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Resource name of the settings. Required for the
            [SecuritySettingsService.UpdateSecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettingsService.UpdateSecuritySettings]
            method.
            [SecuritySettingsService.CreateSecuritySettings][google.cloud.dialogflow.cx.v3beta1.SecuritySettingsService.CreateSecuritySettings]
            populates the name automatically. Format:
            ``projects/<Project ID>/locations/<Location ID>/securitySettings/<Security Settings ID>``.
        display_name (str):
            Required. The human-readable name of the
            security settings, unique within the location.
        redaction_strategy (google.cloud.dialogflowcx_v3beta1.types.SecuritySettings.RedactionStrategy):
            Strategy that defines how we do redaction.
        redaction_scope (google.cloud.dialogflowcx_v3beta1.types.SecuritySettings.RedactionScope):
            Defines the data for which Dialogflow applies
            redaction. Dialogflow does not redact data that
            it does not have access to – for example, Cloud
            logging.
        inspect_template (str):
            `DLP <https://cloud.google.com/dlp/docs>`__ inspect template
            name. Use this template to define inspect base settings.

            The ``DLP Inspect Templates Reader`` role is needed on the
            Dialogflow service identity service account (has the form
            ``service-PROJECT_NUMBER@gcp-sa-dialogflow.iam.gserviceaccount.com``)
            for your agent's project.

            If empty, we use the default DLP inspect config.

            The template name will have one of the following formats:
            ``projects/<Project ID>/locations/<Location ID>/inspectTemplates/<Template ID>``
            OR
            ``organizations/<Organization ID>/locations/<Location ID>/inspectTemplates/<Template ID>``

            Note: ``inspect_template`` must be located in the same
            region as the ``SecuritySettings``.
        deidentify_template (str):
            `DLP <https://cloud.google.com/dlp/docs>`__ deidentify
            template name. Use this template to define de-identification
            configuration for the content.

            The ``DLP De-identify Templates Reader`` role is needed on
            the Dialogflow service identity service account (has the
            form
            ``service-PROJECT_NUMBER@gcp-sa-dialogflow.iam.gserviceaccount.com``)
            for your agent's project.

            If empty, Dialogflow replaces sensitive info with
            ``[redacted]`` text.

            The template name will have one of the following formats:
            ``projects/<Project ID>/locations/<Location ID>/deidentifyTemplates/<Template ID>``
            OR
            ``organizations/<Organization ID>/locations/<Location ID>/deidentifyTemplates/<Template ID>``

            Note: ``deidentify_template`` must be located in the same
            region as the ``SecuritySettings``.
        retention_window_days (int):
            Retains data in interaction logging for the
            specified number of days. This does not apply to
            Cloud logging, which is owned by the user - not
            Dialogflow.
            User must set a value lower than Dialogflow's
            default 365d TTL (30 days for Agent Assist
            traffic), higher value will be ignored and use
            default. Setting a value higher than that has no
            effect. A missing value or setting to 0 also
            means we use default TTL.

            This field is a member of `oneof`_ ``data_retention``.
        purge_data_types (MutableSequence[google.cloud.dialogflowcx_v3beta1.types.SecuritySettings.PurgeDataType]):
            List of types of data to remove when
            retention settings triggers purge.
        audio_export_settings (google.cloud.dialogflowcx_v3beta1.types.SecuritySettings.AudioExportSettings):
            Controls audio export settings for post-conversation
            analytics when ingesting audio to conversations via
            [Participants.AnalyzeContent][] or
            [Participants.StreamingAnalyzeContent][].

            If
            [retention_strategy][google.cloud.dialogflow.cx.v3beta1.SecuritySettings.retention_strategy]
            is set to REMOVE_AFTER_CONVERSATION or
            [audio_export_settings.gcs_bucket][] is empty, audio export
            is disabled.

            If audio export is enabled, audio is recorded and saved to
            [audio_export_settings.gcs_bucket][], subject to retention
            policy of [audio_export_settings.gcs_bucket][].

            This setting won't effect audio input for implicit sessions
            via
            [Sessions.DetectIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.DetectIntent]
            or
            [Sessions.StreamingDetectIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.StreamingDetectIntent].
        insights_export_settings (google.cloud.dialogflowcx_v3beta1.types.SecuritySettings.InsightsExportSettings):
            Controls conversation exporting settings to Insights after
            conversation is completed.

            If
            [retention_strategy][google.cloud.dialogflow.cx.v3beta1.SecuritySettings.retention_strategy]
            is set to REMOVE_AFTER_CONVERSATION, Insights export is
            disabled no matter what you configure here.
    """

    class RedactionStrategy(proto.Enum):
        r"""Defines how we redact data.

        Values:
            REDACTION_STRATEGY_UNSPECIFIED (0):
                Do not redact.
            REDACT_WITH_SERVICE (1):
                Call redaction service to clean up the data
                to be persisted.
        """
        REDACTION_STRATEGY_UNSPECIFIED = 0
        REDACT_WITH_SERVICE = 1

    class RedactionScope(proto.Enum):
        r"""Defines what types of data to redact.

        Values:
            REDACTION_SCOPE_UNSPECIFIED (0):
                Don't redact any kind of data.
            REDACT_DISK_STORAGE (2):
                On data to be written to disk or similar
                devices that are capable of holding data even if
                power is disconnected. This includes data that
                are temporarily saved on disk.
        """
        REDACTION_SCOPE_UNSPECIFIED = 0
        REDACT_DISK_STORAGE = 2

    class PurgeDataType(proto.Enum):
        r"""Type of data we purge after retention settings triggers
        purge.

        Values:
            PURGE_DATA_TYPE_UNSPECIFIED (0):
                Unspecified. Do not use.
            DIALOGFLOW_HISTORY (1):
                Dialogflow history. This does not include
                Cloud logging, which is owned by the user - not
                Dialogflow.
        """
        PURGE_DATA_TYPE_UNSPECIFIED = 0
        DIALOGFLOW_HISTORY = 1

    class AudioExportSettings(proto.Message):
        r"""Settings for exporting audio.

        Attributes:
            gcs_bucket (str):
                Cloud Storage bucket to export audio record
                to. Setting this field would grant the Storage
                Object Creator role to the Dialogflow Service
                Agent.
                API caller that tries to modify this field
                should have the permission of
                storage.buckets.setIamPolicy.
            audio_export_pattern (str):
                Filename pattern for exported audio.
            enable_audio_redaction (bool):
                Enable audio redaction if it is true.
            audio_format (google.cloud.dialogflowcx_v3beta1.types.SecuritySettings.AudioExportSettings.AudioFormat):
                File format for exported audio file.
                Currently only in telephony recordings.
        """

        class AudioFormat(proto.Enum):
            r"""File format for exported audio file. Currently only in
            telephony recordings.

            Values:
                AUDIO_FORMAT_UNSPECIFIED (0):
                    Unspecified. Do not use.
                MULAW (1):
                    G.711 mu-law PCM with 8kHz sample rate.
                MP3 (2):
                    MP3 file format.
                OGG (3):
                    OGG Vorbis.
            """
            AUDIO_FORMAT_UNSPECIFIED = 0
            MULAW = 1
            MP3 = 2
            OGG = 3

        gcs_bucket: str = proto.Field(
            proto.STRING,
            number=1,
        )
        audio_export_pattern: str = proto.Field(
            proto.STRING,
            number=2,
        )
        enable_audio_redaction: bool = proto.Field(
            proto.BOOL,
            number=3,
        )
        audio_format: "SecuritySettings.AudioExportSettings.AudioFormat" = proto.Field(
            proto.ENUM,
            number=4,
            enum="SecuritySettings.AudioExportSettings.AudioFormat",
        )

    class InsightsExportSettings(proto.Message):
        r"""Settings for exporting conversations to
        `Insights <https://cloud.google.com/contact-center/insights/docs>`__.

        Attributes:
            enable_insights_export (bool):
                If enabled, we will automatically exports
                conversations to Insights and Insights runs its
                analyzers.
        """

        enable_insights_export: bool = proto.Field(
            proto.BOOL,
            number=1,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    redaction_strategy: RedactionStrategy = proto.Field(
        proto.ENUM,
        number=3,
        enum=RedactionStrategy,
    )
    redaction_scope: RedactionScope = proto.Field(
        proto.ENUM,
        number=4,
        enum=RedactionScope,
    )
    inspect_template: str = proto.Field(
        proto.STRING,
        number=9,
    )
    deidentify_template: str = proto.Field(
        proto.STRING,
        number=17,
    )
    retention_window_days: int = proto.Field(
        proto.INT32,
        number=6,
        oneof="data_retention",
    )
    purge_data_types: MutableSequence[PurgeDataType] = proto.RepeatedField(
        proto.ENUM,
        number=8,
        enum=PurgeDataType,
    )
    audio_export_settings: AudioExportSettings = proto.Field(
        proto.MESSAGE,
        number=12,
        message=AudioExportSettings,
    )
    insights_export_settings: InsightsExportSettings = proto.Field(
        proto.MESSAGE,
        number=13,
        message=InsightsExportSettings,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.dialogflowcx_v3 import gapic_version as package_version

__version__ = package_version.__version__


from .services.agents import AgentsClient
from .services.agents import AgentsAsyncClient
from .services.changelogs import ChangelogsClient
from .services.changelogs import ChangelogsAsyncClient
from .services.deployments import DeploymentsClient
from .services.deployments import DeploymentsAsyncClient
from .services.entity_types import EntityTypesClient
from .services.entity_types import EntityTypesAsyncClient
from .services.environments import EnvironmentsClient
from .services.environments import EnvironmentsAsyncClient
from .services.experiments import ExperimentsClient
from .services.experiments import ExperimentsAsyncClient
from .services.flows import FlowsClient
from .services.flows import FlowsAsyncClient
from .services.intents import IntentsClient
from .services.intents import IntentsAsyncClient
from .services.pages import PagesClient
from .services.pages import PagesAsyncClient
from .services.security_settings_service import SecuritySettingsServiceClient
from .services.security_settings_service import SecuritySettingsServiceAsyncClient
from .services.session_entity_types import SessionEntityTypesClient
from .services.session_entity_types import SessionEntityTypesAsyncClient
from .services.sessions import SessionsClient
from .services.sessions import SessionsAsyncClient
from .services.test_cases import TestCasesClient
from .services.test_cases import TestCasesAsyncClient
from .services.transition_route_groups import TransitionRouteGroupsClient
from .services.transition_route_groups import TransitionRouteGroupsAsyncClient
from .services.versions import VersionsClient
from .services.versions import VersionsAsyncClient
from .services.webhooks import WebhooksClient
from .services.webhooks import WebhooksAsyncClient

from .types.advanced_settings import AdvancedSettings
from .types.agent import Agent
from .types.agent import AgentValidationResult
from .types.agent import CreateAgentRequest
from .types.agent import DeleteAgentRequest
from .types.agent import ExportAgentRequest
from .types.agent import ExportAgentResponse
from .types.agent import GetAgentRequest
from .types.agent import GetAgentValidationResultRequest
from .types.agent import ListAgentsRequest
from .types.agent import ListAgentsResponse
from .types.agent import RestoreAgentRequest
from .types.agent import SpeechToTextSettings
from .types.agent import UpdateAgentRequest
from .types.agent import ValidateAgentRequest
from .types.audio_config import InputAudioConfig
from .types.audio_config import OutputAudioConfig
from .types.audio_config import SpeechWordInfo
from .types.audio_config import SynthesizeSpeechConfig
from .types.audio_config import TextToSpeechSettings
from .types.audio_config import VoiceSelectionParams
from .types.audio_config import AudioEncoding
from .types.audio_config import OutputAudioEncoding
from .types.audio_config import SpeechModelVariant
from .types.audio_config import SsmlVoiceGender
from .types.changelog import Changelog
from .types.changelog import GetChangelogRequest
from .types.changelog import ListChangelogsRequest
from .types.changelog import ListChangelogsResponse
from .types.deployment import Deployment
from .types.deployment import GetDeploymentRequest
from .types.deployment import ListDeploymentsRequest
from .types.deployment import ListDeploymentsResponse
from .types.entity_type import CreateEntityTypeRequest
from .types.entity_type import DeleteEntityTypeRequest
from .types.entity_type import EntityType
from .types.entity_type import GetEntityTypeRequest
from .types.entity_type import ListEntityTypesRequest
from .types.entity_type import ListEntityTypesResponse
from .types.entity_type import UpdateEntityTypeRequest
from .types.environment import ContinuousTestResult
from .types.environment import CreateEnvironmentRequest
from .types.environment import DeleteEnvironmentRequest
from .types.environment import DeployFlowMetadata
from .types.environment import DeployFlowRequest
from .types.environment import DeployFlowResponse
from .types.environment import Environment
from .types.environment import GetEnvironmentRequest
from .types.environment import ListContinuousTestResultsRequest
from .types.environment import ListContinuousTestResultsResponse
from .types.environment import ListEnvironmentsRequest
from .types.environment import ListEnvironmentsResponse
from .types.environment import LookupEnvironmentHistoryRequest
from .types.environment import LookupEnvironmentHistoryResponse
from .types.environment import RunContinuousTestMetadata
from .types.environment import RunContinuousTestRequest
from .types.environment import RunContinuousTestResponse
from .types.environment import UpdateEnvironmentRequest
from .types.experiment import CreateExperimentRequest
from .types.experiment import DeleteExperimentRequest
from .types.experiment import Experiment
from .types.experiment import GetExperimentRequest
from .types.experiment import ListExperimentsRequest
from .types.experiment import ListExperimentsResponse
from .types.experiment import RolloutConfig
from .types.experiment import RolloutState
from .types.experiment import StartExperimentRequest
from .types.experiment import StopExperimentRequest
from .types.experiment import UpdateExperimentRequest
from .types.experiment import VariantsHistory
from .types.experiment import VersionVariants
from .types.flow import CreateFlowRequest
from .types.flow import DeleteFlowRequest
from .types.flow import ExportFlowRequest
from .types.flow import ExportFlowResponse
from .types.flow import Flow
from .types.flow import FlowValidationResult
from .types.flow import GetFlowRequest
from .types.flow import GetFlowValidationResultRequest
from .types.flow import ImportFlowRequest
from .types.flow import ImportFlowResponse
from .types.flow import ListFlowsRequest
from .types.flow import ListFlowsResponse
from .types.flow import NluSettings
from .types.flow import TrainFlowRequest
from .types.flow import UpdateFlowRequest
from .types.flow import ValidateFlowRequest
from .types.fulfillment import Fulfillment
from .types.gcs import GcsDestination
from .types.intent import CreateIntentRequest
from .types.intent import DeleteIntentRequest
from .types.intent import GetIntentRequest
from .types.intent import Intent
from .types.intent import ListIntentsRequest
from .types.intent import ListIntentsResponse
from .types.intent import UpdateIntentRequest
from .types.intent import IntentView
from .types.page import CreatePageRequest
from .types.page import DeletePageRequest
from .types.page import EventHandler
from .types.page import Form
from .types.page import GetPageRequest
from .types.page import ListPagesRequest
from .types.page import ListPagesResponse
from .types.page import Page
from .types.page import TransitionRoute
from .types.page import UpdatePageRequest
from .types.response_message import ResponseMessage
from .types.security_settings import CreateSecuritySettingsRequest
from .types.security_settings import DeleteSecuritySettingsRequest
from .types.security_settings import GetSecuritySettingsRequest
from .types.security_settings import ListSecuritySettingsRequest
from .types.security_settings import ListSecuritySettingsResponse
from .types.security_settings import SecuritySettings
from .types.security_settings import UpdateSecuritySettingsRequest
from .types.session import AudioInput
from .types.session import CloudConversationDebuggingInfo
from .types.session import DetectIntentRequest
from .types.session import DetectIntentResponse
from .types.session import DtmfInput
from .types.session import EventInput
from .types.session import FulfillIntentRequest
from .types.session import FulfillIntentResponse
from .types.session import IntentInput
from .types.session import Match
from .types.session import MatchIntentRequest
from .types.session import MatchIntentResponse
from .types.session import QueryInput
from .types.session import QueryParameters
from .types.session import QueryResult
from .types.session import SentimentAnalysisResult
from .types.session import StreamingDetectIntentRequest
from .types.session import StreamingDetectIntentResponse
from .types.session import StreamingRecognitionResult
from .types.session import TextInput
from .types.session_entity_type import CreateSessionEntityTypeRequest
from .types.session_entity_type import DeleteSessionEntityTypeRequest
from .types.session_entity_type import GetSessionEntityTypeRequest
from .types.session_entity_type import ListSessionEntityTypesRequest
from .types.session_entity_type import ListSessionEntityTypesResponse
from .types.session_entity_type import SessionEntityType
from .types.session_entity_type import UpdateSessionEntityTypeRequest
from .types.test_case import BatchDeleteTestCasesRequest
from .types.test_case import BatchRunTestCasesMetadata
from .types.test_case import BatchRunTestCasesRequest
from .types.test_case import BatchRunTestCasesResponse
from .types.test_case import CalculateCoverageRequest
from .types.test_case import CalculateCoverageResponse
from .types.test_case import ConversationTurn
from .types.test_case import CreateTestCaseRequest
from .types.test_case import ExportTestCasesMetadata
from .types.test_case import ExportTestCasesRequest
from .types.test_case import ExportTestCasesResponse
from .types.test_case import GetTestCaseRequest
from .types.test_case import GetTestCaseResultRequest
from .types.test_case import ImportTestCasesMetadata
from .types.test_case import ImportTestCasesRequest
from .types.test_case import ImportTestCasesResponse
from .types.test_case import IntentCoverage
from .types.test_case import ListTestCaseResultsRequest
from .types.test_case import ListTestCaseResultsResponse
from .types.test_case import ListTestCasesRequest
from .types.test_case import ListTestCasesResponse
from .types.test_case import RunTestCaseMetadata
from .types.test_case import RunTestCaseRequest
from .types.test_case import RunTestCaseResponse
from .types.test_case import TestCase
from .types.test_case import TestCaseError
from .types.test_case import TestCaseResult
from .types.test_case import TestConfig
from .types.test_case import TestError
from .types.test_case import TestRunDifference
from .types.test_case import TransitionCoverage
from .types.test_case import TransitionRouteGroupCoverage
from .types.test_case import UpdateTestCaseRequest
from .types.test_case import TestResult
from .types.transition_route_group import CreateTransitionRouteGroupRequest
from .types.transition_route_group import DeleteTransitionRouteGroupRequest
from .types.transition_route_group import GetTransitionRouteGroupRequest
from .types.transition_route_group import ListTransitionRouteGroupsRequest
from .types.transition_route_group import ListTransitionRouteGroupsResponse
from .types.transition_route_group import TransitionRouteGroup
from .types.transition_route_group import UpdateTransitionRouteGroupRequest
from .types.validation_message import ResourceName
from .types.validation_message import ValidationMessage
from .types.version import CompareVersionsRequest
from .types.version import CompareVersionsResponse
from .types.version import CreateVersionOperationMetadata
from .types.version import CreateVersionRequest
from .types.version import DeleteVersionRequest
from .types.version import GetVersionRequest
from .types.version import ListVersionsRequest
from .types.version import ListVersionsResponse
from .types.version import LoadVersionRequest
from .types.version import UpdateVersionRequest
from .types.version import Version
from .types.webhook import CreateWebhookRequest
from .types.webhook import DeleteWebhookRequest
from .types.webhook import GetWebhookRequest
from .types.webhook import ListWebhooksRequest
from .types.webhook import ListWebhooksResponse
from .types.webhook import PageInfo
from .types.webhook import SessionInfo
from .types.webhook import UpdateWebhookRequest
from .types.webhook import Webhook
from .types.webhook import WebhookRequest
from .types.webhook import WebhookResponse

__all__ = (
    "AgentsAsyncClient",
    "ChangelogsAsyncClient",
    "DeploymentsAsyncClient",
    "EntityTypesAsyncClient",
    "EnvironmentsAsyncClient",
    "ExperimentsAsyncClient",
    "FlowsAsyncClient",
    "IntentsAsyncClient",
    "PagesAsyncClient",
    "SecuritySettingsServiceAsyncClient",
    "SessionEntityTypesAsyncClient",
    "SessionsAsyncClient",
    "TestCasesAsyncClient",
    "TransitionRouteGroupsAsyncClient",
    "VersionsAsyncClient",
    "WebhooksAsyncClient",
    "AdvancedSettings",
    "Agent",
    "AgentValidationResult",
    "AgentsClient",
    "AudioEncoding",
    "AudioInput",
    "BatchDeleteTestCasesRequest",
    "BatchRunTestCasesMetadata",
    "BatchRunTestCasesRequest",
    "BatchRunTestCasesResponse",
    "CalculateCoverageRequest",
    "CalculateCoverageResponse",
    "Changelog",
    "ChangelogsClient",
    "CloudConversationDebuggingInfo",
    "CompareVersionsRequest",
    "CompareVersionsResponse",
    "ContinuousTestResult",
    "ConversationTurn",
    "CreateAgentRequest",
    "CreateEntityTypeRequest",
    "CreateEnvironmentRequest",
    "CreateExperimentRequest",
    "CreateFlowRequest",
    "CreateIntentRequest",
    "CreatePageRequest",
    "CreateSecuritySettingsRequest",
    "CreateSessionEntityTypeRequest",
    "CreateTestCaseRequest",
    "CreateTransitionRouteGroupRequest",
    "CreateVersionOperationMetadata",
    "CreateVersionRequest",
    "CreateWebhookRequest",
    "DeleteAgentRequest",
    "DeleteEntityTypeRequest",
    "DeleteEnvironmentRequest",
    "DeleteExperimentRequest",
    "DeleteFlowRequest",
    "DeleteIntentRequest",
    "DeletePageRequest",
    "DeleteSecuritySettingsRequest",
    "DeleteSessionEntityTypeRequest",
    "DeleteTransitionRouteGroupRequest",
    "DeleteVersionRequest",
    "DeleteWebhookRequest",
    "DeployFlowMetadata",
    "DeployFlowRequest",
    "DeployFlowResponse",
    "Deployment",
    "DeploymentsClient",
    "DetectIntentRequest",
    "DetectIntentResponse",
    "DtmfInput",
    "EntityType",
    "EntityTypesClient",
    "Environment",
    "EnvironmentsClient",
    "EventHandler",
    "EventInput",
    "Experiment",
    "ExperimentsClient",
    "ExportAgentRequest",
    "ExportAgentResponse",
    "ExportFlowRequest",
    "ExportFlowResponse",
    "ExportTestCasesMetadata",
    "ExportTestCasesRequest",
    "ExportTestCasesResponse",
    "Flow",
    "FlowValidationResult",
    "FlowsClient",
    "Form",
    "FulfillIntentRequest",
    "FulfillIntentResponse",
    "Fulfillment",
    "GcsDestination",
    "GetAgentRequest",
    "GetAgentValidationResultRequest",
    "GetChangelogRequest",
    "GetDeploymentRequest",
    "GetEntityTypeRequest",
    "GetEnvironmentRequest",
    "GetExperimentRequest",
    "GetFlowRequest",
    "GetFlowValidationResultRequest",
    "GetIntentRequest",
    "GetPageRequest",
    "GetSecuritySettingsRequest",
    "GetSessionEntityTypeRequest",
    "GetTestCaseRequest",
    "GetTestCaseResultRequest",
    "GetTransitionRouteGroupRequest",
    "GetVersionRequest",
    "GetWebhookRequest",
    "ImportFlowRequest",
    "ImportFlowResponse",
    "ImportTestCasesMetadata",
    "ImportTestCasesRequest",
    "ImportTestCasesResponse",
    "InputAudioConfig",
    "Intent",
    "IntentCoverage",
    "IntentInput",
    "IntentView",
    "IntentsClient",
    "ListAgentsRequest",
    "ListAgentsResponse",
    "ListChangelogsRequest",
    "ListChangelogsResponse",
    "ListContinuousTestResultsRequest",
    "ListContinuousTestResultsResponse",
    "ListDeploymentsRequest",
    "ListDeploymentsResponse",
    "ListEntityTypesRequest",
    "ListEntityTypesResponse",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "ListExperimentsRequest",
    "ListExperimentsResponse",
    "ListFlowsRequest",
    "ListFlowsResponse",
    "ListIntentsRequest",
    "ListIntentsResponse",
    "ListPagesRequest",
    "ListPagesResponse",
    "ListSecuritySettingsRequest",
    "ListSecuritySettingsResponse",
    "ListSessionEntityTypesRequest",
    "ListSessionEntityTypesResponse",
    "ListTestCaseResultsRequest",
    "ListTestCaseResultsResponse",
    "ListTestCasesRequest",
    "ListTestCasesResponse",
    "ListTransitionRouteGroupsRequest",
    "ListTransitionRouteGroupsResponse",
    "ListVersionsRequest",
    "ListVersionsResponse",
    "ListWebhooksRequest",
    "ListWebhooksResponse",
    "LoadVersionRequest",
    "LookupEnvironmentHistoryRequest",
    "LookupEnvironmentHistoryResponse",
    "Match",
    "MatchIntentRequest",
    "MatchIntentResponse",
    "NluSettings",
    "OutputAudioConfig",
    "OutputAudioEncoding",
    "Page",
    "PageInfo",
    "PagesClient",
    "QueryInput",
    "QueryParameters",
    "QueryResult",
    "ResourceName",
    "ResponseMessage",
    "RestoreAgentRequest",
    "RolloutConfig",
    "RolloutState",
    "RunContinuousTestMetadata",
    "RunContinuousTestRequest",
    "RunContinuousTestResponse",
    "RunTestCaseMetadata",
    "RunTestCaseRequest",
    "RunTestCaseResponse",
    "SecuritySettings",
    "SecuritySettingsServiceClient",
    "SentimentAnalysisResult",
    "SessionEntityType",
    "SessionEntityTypesClient",
    "SessionInfo",
    "SessionsClient",
    "SpeechModelVariant",
    "SpeechToTextSettings",
    "SpeechWordInfo",
    "SsmlVoiceGender",
    "StartExperimentRequest",
    "StopExperimentRequest",
    "StreamingDetectIntentRequest",
    "StreamingDetectIntentResponse",
    "StreamingRecognitionResult",
    "SynthesizeSpeechConfig",
    "TestCase",
    "TestCaseError",
    "TestCaseResult",
    "TestCasesClient",
    "TestConfig",
    "TestError",
    "TestResult",
    "TestRunDifference",
    "TextInput",
    "TextToSpeechSettings",
    "TrainFlowRequest",
    "TransitionCoverage",
    "TransitionRoute",
    "TransitionRouteGroup",
    "TransitionRouteGroupCoverage",
    "TransitionRouteGroupsClient",
    "UpdateAgentRequest",
    "UpdateEntityTypeRequest",
    "UpdateEnvironmentRequest",
    "UpdateExperimentRequest",
    "UpdateFlowRequest",
    "UpdateIntentRequest",
    "UpdatePageRequest",
    "UpdateSecuritySettingsRequest",
    "UpdateSessionEntityTypeRequest",
    "UpdateTestCaseRequest",
    "UpdateTransitionRouteGroupRequest",
    "UpdateVersionRequest",
    "UpdateWebhookRequest",
    "ValidateAgentRequest",
    "ValidateFlowRequest",
    "ValidationMessage",
    "VariantsHistory",
    "Version",
    "VersionVariants",
    "VersionsClient",
    "VoiceSelectionParams",
    "Webhook",
    "WebhookRequest",
    "WebhookResponse",
    "WebhooksClient",
)
